==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_db.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_db.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("DBLAN_1", "Core settings backed up in database.");
define("DBLAN_2", "Click button to save a backup of your e107 database");
define("DBLAN_3", "Backup SQL database");
define("DBLAN_4", "Click button to check validity of e107 database");
define("DBLAN_5", "Check database validity");
define("DBLAN_6", "Click button to optimize your e107 database");
define("DBLAN_7", "Optimize SQL database");
define("DBLAN_8", "Click button to backup your core settings");
define("DBLAN_9", "Backup core");
define("DBLAN_10", "Database Utilities");
define("DBLAN_11", "MySQL database");
define("DBLAN_12", "optimized");
define("DBLAN_13", "Back");
define("DBLAN_14", "Done");
define("DBLAN_15", "Click button to check for any available db updates");
define("DBLAN_16", "Check for Updates");
define("DBLAN_17", "Pref. Name");
define("DBLAN_18", "Pref. Value");
define("DBLAN_19", "Click button to open the preferences editor (for advanced users only)");
define("DBLAN_20", "Preferences Editor");
define("DBLAN_21", "Delete Checked");
define("DBLAN_22", "Plugin: View and Scan");
define("DBLAN_23", "Scan Completed");
define("DBLAN_24", "Name");
define("DBLAN_25", "Directory");
define("DBLAN_26", "Included add-ons");
define("DBLAN_27", "Installed");
define("DBLAN_28", "Click button to scan plugin directories for changes");
define("DBLAN_29", "Scan plugin directories");
define("DBLAN_30", " (If an addon shows an error, check for characters outside the PHP opening/closing tags)");
define("DBLAN_31", "Pass");
define("DBLAN_32", "Error");
define("DBLAN_33", "Inaccessible");
define("DBLAN_34", "Not checked");
define('DBLAN_35', 'Click button to check validity of user table');
define('DBLAN_36', 'Check user table');


?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/admin/lan_db.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_db.php $
|     $Revision: 11678 $
|     $Id: lan_db.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("DBLAN_1", "Core settings backed up in database.");
define("DBLAN_2", "Click button to save a backup of your e107 database");
define("DBLAN_3", "Backup SQL database");
define("DBLAN_4", "Click button to check validity of e107 database");
define("DBLAN_5", "Check database validity");
define("DBLAN_6", "Click button to optimize your e107 database");
define("DBLAN_7", "Optimize SQL database");
define("DBLAN_8", "Click button to backup your core settings");
define("DBLAN_9", "Backup core");
define("DBLAN_10", "Database Utilities");
define("DBLAN_11", "MySQL database");
define("DBLAN_12", "optimized");
define("DBLAN_13", "Back");
define("DBLAN_14", "Done");
define("DBLAN_15", "Click button to check for any available db updates");
define("DBLAN_16", "Check for Updates");
define("DBLAN_17", "Pref. Name");
define("DBLAN_18", "Pref. Value");
define("DBLAN_19", "Click button to open the preferences editor (for advanced users only)");
define("DBLAN_20", "Preferences Editor");
define("DBLAN_21", "Delete Checked");
define("DBLAN_22", "Plugin: View and Scan");
define("DBLAN_23", "Scan Completed");
define("DBLAN_24", "Name");
define("DBLAN_25", "Directory");
define("DBLAN_26", "Included add-ons");
define("DBLAN_27", "Installed");
define("DBLAN_28", "Click button to scan plugin directories for changes");
define("DBLAN_29", "Scan plugin directories");
define("DBLAN_30", " (If an addon shows an error, check for characters outside the PHP opening/closing tags)");
define("DBLAN_31", "Pass");
define("DBLAN_32", "Error");
define("DBLAN_33", "Inaccessible");
define("DBLAN_34", "Not checked");
define('DBLAN_35', 'Click button to check validity of user table');
define('DBLAN_36', 'Check user table');


?>
